==> phpmyadmin-sql-parser_4.6.1.orig.tar.gz: sql-parser-4.6.1/tests/Utils/RoutineTest.php <==
<?php

namespace PhpMyAdmin\SqlParser\Tests\Utils;

use PhpMyAdmin\SqlParser\Parser;
use PhpMyAdmin\SqlParser\Tests\TestCase;
use PhpMyAdmin\SqlParser\Utils\Routine;

class RoutineTest extends TestCase
{
    /**
     * @dataProvider getReturnTypeProvider
     *
     * @param mixed $def
     */
    public function testGetReturnType($def, array $expected)
    {
        $this->assertEquals($expected, Routine::getReturnType($def));
    }

    public function getReturnTypeProvider()
    {
        return array(
            array(
                '',
                array(
                    '',
                    '',
                    '',
                    '',
                    '',
                ),
            ),
            array(
                'TEXT',
                array(
                    '',
                    '',
                    'TEXT',
                    '',
                    '',
                ),
            ),
            array(
                'INT(20)',
                array(
                    '',
                    '',
                    'INT',
                    '20',
                    '',
                ),
            ),
            array(
                'INT UNSIGNED',
                array(
                    '',
                    '',
                    'INT',
                    '',
                    'UNSIGNED',
                ),
            ),
            array(
                'VARCHAR(1) CHARSET utf8',
                array(
                    '',
                    '',
                    'VARCHAR',
                    '1',
                    'utf8',
                ),
            ),
            array(
                'ENUM(\'a\', \'b\') CHARSET latin1',
                array(
                    '',
                    '',
                    'ENUM',
                    '\'a\',\'b\'',
                    'latin1',
                ),
            ),
            array(
                'DECIMAL(5,2) UNSIGNED ZEROFILL',
                array(
                    '',
                    '',
                    'DECIMAL',
                    '5,2',
                    'UNSIGNED ZEROFILL',
                ),
            ),
            array(
                'SET(\'test\'\'esc"\',   \'more\\\'esc\')',
                array(
                    '',
                    '',
                    'SET',
                    '\'test\'\'esc"\',\'more\\\'esc\'',
                    '',
                ),
            )
        );
    }

    /**
     * @dataProvider getParameterProvider
     *
     * @param mixed $def
     */
    public function testGetParameter($def, array $expected)
    {
        $this->assertEquals($expected, Routine::getParameter($def));
    }

    public function getParameterProvider()
    {
        return array(
            array(
                '',
                array(
                    '',
                    '',
                    '',
                    '',
                    '',
                ),
            ),
            array(
                '`foo` TEXT',
                array(
                    '',
                    'foo',
                    'TEXT',
                    '',
                    '',
                ),
            ),
            array(
                '`foo` INT(20)',
                array(
                    '',
                    'foo',
                    'INT',
                    '20',
                    '',
                ),
            ),
            array(
                'IN `fo``fo` INT UNSIGNED',
                array(
                    'IN',
                    'fo`fo',
                    'INT',
                    '',
                    'UNSIGNED',
                ),
            ),
            array(
                'OUT bar VARCHAR(1) CHARSET utf8',
                array(
                    'OUT',
                    'bar',
                    'VARCHAR',
                    '1',
                    'utf8',
                ),
            ),
            array(
                '`"baz\'\'` ENUM(\'a\', \'b\') CHARSET latin1',
                array(
                    '',
                    '"baz\'\'',
                    'ENUM',
                    '\'a\',\'b\'',
                    'latin1',
                ),
            ),
            array(
                'INOUT `foo` DECIMAL(5,2) UNSIGNED ZEROFILL',
                array(
                    'INOUT',
                    'foo',
                    'DECIMAL',
                    '5,2',
                    'UNSIGNED ZEROFILL',
                ),
            ),
            array(
                '`foo``s func` SET(\'test\'\'esc"\',   \'more\\\'esc\')',
                array(
                    '',
                    'foo`s func',
                    'SET',
                    '\'test\'\'esc"\',\'more\\\'esc\'',
                    '',
                ),
            )
        );
    }

    /**
     * @dataProvider getParametersProvider
     *
     * @param mixed $query
     */
    public function testGetParameters($query, array $expected)
    {
        $parser = new Parser($query);
        $this->assertEquals($expected, Routine::getParameters($parser->statements[0]));
    }

    public function getParametersProvider()
    {
        return array(
            array(
                'CREATE PROCEDURE `foo`() SET @A=0',
                array(
                    'num' => 0,
                    'dir' => array(),
                    'name' => array(),
                    'type' => array(),
                    'length' => array(),
                    'length_arr' => array(),
                    'opts' => array(),
                ),
            ),
            array(
                'CREATE DEFINER=`user\\`@`somehost``(` FUNCTION `foo```(`baz` INT) BEGIN SELECT NULL; END',
                array(
                    'num' => 1,
                    'dir' => array(
                        0 => '',
                    ),
                    'name' => array(
                        0 => 'baz',
                    ),
                    'type' => array(
                        0 => 'INT',
                    ),
                    'length' => array(
                        0 => '',
                    ),
                    'length_arr' => array(
                        0 => array(),
                    ),
                    'opts' => array(
                        0 => '',
                    ),
                ),
            ),
            array(
                'CREATE PROCEDURE `foo`(IN `baz\\)` INT(25) zerofill unsigned) BEGIN SELECT NULL; END',
                array(
                    'num' => 1,
                    'dir' => array(
                        0 => 'IN',
                    ),
                    'name' => array(
                        0 => 'baz\\)',
                    ),
                    'type' => array(
                        0 => 'INT',
                    ),
                    'length' => array(
                        0 => '25',
                    ),
                    'length_arr' => array(
                        0 => array('25'),
                    ),
                    'opts' => array(
                        0 => 'UNSIGNED ZEROFILL',
                    ),
                ),
            ),
            array(
                'CREATE PROCEDURE `foo`(IN `baz\\` INT(001) zerofill, out bazz varchar(15) charset utf8) ' .
                'BEGIN SELECT NULL; END',
                array(
                    'num' => 2,
                    'dir' => array(
                        0 => 'IN',
                        1 => 'OUT',
                    ),
                    'name' => array(
                        0 => 'baz\\',
                        1 => 'bazz',
                    ),
                    'type' => array(
                        0 => 'INT',
                        1 => 'VARCHAR',
                    ),
                    'length' => array(
                        0 => '1',
                        1 => '15',
                    ),
                    'length_arr' => array(
                        0 => array('1'),
                        1 => array('15'),
                    ),
                    'opts' => array(
                        0 => 'ZEROFILL',
                        1 => 'utf8',
                    ),
                ),
            )
        );
    }
}

==> phpmyadmin-sql-parser_5.4.1.orig.tar.gz: sql-parser-5.4.1/tests/Utils/RoutineTest.php <==
<?php

declare(strict_types=1);

namespace PhpMyAdmin\SqlParser\Tests\Utils;

use PhpMyAdmin\SqlParser\Parser;
use PhpMyAdmin\SqlParser\Tests\TestCase;
use PhpMyAdmin\SqlParser\Utils\Routine;

class RoutineTest extends TestCase
{
    /**
     * @param mixed $def
     *
     * @dataProvider getReturnTypeProvider
     */
    public function testGetReturnType($def, array $expected)
    {
        $this->assertEquals($expected, Routine::getReturnType($def));
    }

    public function getReturnTypeProvider()
    {
        return [
            [
                '',
                [
                    '',
                    '',
                    '',
                    '',
                    '',
                ],
            ],
            [
                'TEXT',
                [
                    '',
                    '',
                    'TEXT',
                    '',
                    '',
                ],
            ],
            [
                'INT(20)',
                [
                    '',
                    '',
                    'INT',
                    '20',
                    '',
                ],
            ],
            [
                'INT UNSIGNED',
                [
                    '',
                    '',
                    'INT',
                    '',
                    'UNSIGNED',
                ],
            ],
            [
                'VARCHAR(1) CHARSET utf8',
                [
                    '',
                    '',
                    'VARCHAR',
                    '1',
                    'utf8',
                ],
            ],
            [
                'ENUM(\'a\', \'b\') CHARSET latin1',
                [
                    '',
                    '',
                    'ENUM',
                    '\'a\',\'b\'',
                    'latin1',
                ],
            ],
            [
                'DECIMAL(5,2) UNSIGNED ZEROFILL',
                [
                    '',
                    '',
                    'DECIMAL',
                    '5,2',
                    'UNSIGNED ZEROFILL',
                ],
            ],
            [
                'SET(\'test\'\'esc"\',   \'more\\\'esc\')',
                [
                    '',
                    '',
                    'SET',
                    '\'test\'\'esc"\',\'more\\\'esc\'',
                    '',
                ],
            ],
        ];
    }

    /**
     * @param mixed $def
     *
     * @dataProvider getParameterProvider
     */
    public function testGetParameter($def, array $expected)
    {
        $this->assertEquals($expected, Routine::getParameter($def));
    }

    public function getParameterProvider()
    {
        return [
            [
                '',
                [
                    '',
                    '',
                    '',
                    '',
                    '',
                ],
            ],
            [
                '`foo` TEXT',
                [
                    '',
                    'foo',
                    'TEXT',
                    '',
                    '',
                ],
            ],
            [
                '`foo` INT(20)',
                [
                    '',
                    'foo',
                    'INT',
                    '20',
                    '',
                ],
            ],
            [
                'IN `fo``fo` INT UNSIGNED',
                [
                    'IN',
                    'fo`fo',
                    'INT',
                    '',
                    'UNSIGNED',
                ],
            ],
            [
                'OUT bar VARCHAR(1) CHARSET utf8',
                [
                    'OUT',
                    'bar',
                    'VARCHAR',
                    '1',
                    'utf8',
                ],
            ],
            [
                '`"baz\'\'` ENUM(\'a\', \'b\') CHARSET latin1',
                [
                    '',
                    '"baz\'\'',
                    'ENUM',
                    '\'a\',\'b\'',
                    'latin1',
                ],
            ],
            [
                'INOUT `foo` DECIMAL(5,2) UNSIGNED ZEROFILL',
                [
                    'INOUT',
                    'foo',
                    'DECIMAL',
                    '5,2',
                    'UNSIGNED ZEROFILL',
                ],
            ],
            [
                '`foo``s func` SET(\'test\'\'esc"\',   \'more\\\'esc\')',
                [
                    '',
                    'foo`s func',
                    'SET',
                    '\'test\'\'esc"\',\'more\\\'esc\'',
                    '',
                ],
            ],
        ];
    }

    /**
     * @param mixed $query
     *
     * @dataProvider getParametersProvider
     */
    public function testGetParameters($query, array $expected)
    {
        $parser = new Parser($query);
        $this->assertEquals($expected, Routine::getParameters($parser->statements[0]));
    }

    public function getParametersProvider()
    {
        return [
            [
                'CREATE PROCEDURE `foo`() SET @A=0',
                [
                    'num' => 0,
                    'dir' => [],
                    'name' => [],
                    'type' => [],
                    'length' => [],
                    'length_arr' => [],
                    'opts' => [],
                ],
            ],
            [
                'CREATE DEFINER=`user\\`@`somehost``(` FUNCTION `foo```(`baz` INT) BEGIN SELECT NULL; END',
                [
                    'num' => 1,
                    'dir' => [0 => ''],
                    'name' => [0 => 'baz'],
                    'type' => [0 => 'INT'],
                    'length' => [0 => ''],
                    'length_arr' => [
                        0 => [],
                    ],
                    'opts' => [0 => ''],
                ],
            ],
            [
                'CREATE PROCEDURE `foo`(IN `baz\\)` INT(25) zerofill unsigned) BEGIN SELECT NULL; END',
                [
                    'num' => 1,
                    'dir' => [0 => 'IN'],
                    'name' => [0 => 'baz\\)'],
                    'type' => [0 => 'INT'],
                    'length' => [0 => '25'],
                    'length_arr' => [
                        0 => ['25'],
                    ],
                    'opts' => [0 => 'UNSIGNED ZEROFILL'],
                ],
            ],
            [
                'CREATE PROCEDURE `foo`(IN `baz\\` INT(001) zerofill, out bazz varchar(15) charset utf8) ' .
                'BEGIN SELECT NULL; END',
                [
                    'num' => 2,
                    'dir' => [
                        0 => 'IN',
                        1 => 'OUT',
                    ],
                    'name' => [
                        0 => 'baz\\',
                        1 => 'bazz',
                    ],
                    'type' => [
                        0 => 'INT',
                        1 => 'VARCHAR',
                    ],
                    'length' => [
                        0 => '1',
                        1 => '15',
                    ],
                    'length_arr' => [
                        0 => ['1'],
                        1 => ['15'],
                    ],
                    'opts' => [
                        0 => 'ZEROFILL',
                        1 => 'utf8',
                    ],
                ],
            ],
        ];
    }
}
